Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(7389)

Unified Diff: chrome/browser/resources/settings/site_settings/site_list.js

Issue 2237823003: Site Settings Desktop: Implement USB devices section. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Address feedback Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/resources/settings/site_settings/site_list.js
diff --git a/chrome/browser/resources/settings/site_settings/site_list.js b/chrome/browser/resources/settings/site_settings/site_list.js
index 8b4aeb309db67ec687e00da0c61306c39e5918a6..81e41ec1cc958fe57847b77dad2705e714363f18 100644
--- a/chrome/browser/resources/settings/site_settings/site_list.js
+++ b/chrome/browser/resources/settings/site_settings/site_list.js
@@ -254,9 +254,11 @@ Polymer({
var promiseList = [];
for (var type in settings.ContentSettingsTypes) {
if (settings.ContentSettingsTypes[type] ==
- settings.ContentSettingsTypes.PROTOCOL_HANDLERS) {
- // Protocol handlers don't have data stored the way all the other
- // categories do.
+ settings.ContentSettingsTypes.PROTOCOL_HANDLERS ||
+ settings.ContentSettingsTypes[type] ==
+ settings.ContentSettingsTypes.USB_DEVICES) {
+ // Protocol handlers and USB devices don't have data stored the way all
+ // the other categories do.
continue;
}

Powered by Google App Engine
This is Rietveld 408576698